import { Client } from '@stomp/stompjs';
import { isObject, get, last } from 'lodash';
let client;
const options = {
  brokerURL: process.env.VUE_APP_MQ_URL,
  connectHeaders: {
    host: process.env.VUE_APP_MQ_HOST,
    login: process.env.VUE_APP_MQ_LOGIN,
    passcode: process.env.VUE_APP_MQ_PASSCODE,
  },
  reconnectDelay: 5000,
  heartbeatIncoming: 4000,
  heartbeatOutgoing: 4000,
};
const initClient = (subscribes) => {
  client = new Client(options);
  client.onConnect = (res) => {
    console.log('is connected');
    if (!isObject(subscribes)) return;
    for (const url in subscribes) {
      const cb = subscribes[url];
      const arr = url.split('/');
      const l = last(arr);
      const arr2 = l.split('.');
      const sign = last(arr2);
      client.subscribe(
        url,
        (msg) => {
          let body = get(msg, 'body');
          if (body) body = JSON.parse(body);
          cb(body);
        },
        { id: sign }
      );
    }
  };
  client.onStompError = (res) => {
    console.log('connect error');
    console.log(res);
  };
  client.activate();
  return client;
};

export { initClient };
